@@ -1,13 +1,8 @@
 ##' Randomly sample response patterns given a list of items
 ##'
 ##' Returns a random sample of response patterns given a list of item
-##' models and parameters.
-##'
-##' The design matrix can accomodate more person abilities than item
-##' dimension. Refer to Cai (2010) for design matrix examples.
-##'
-##' TODO: Add restrictions to design matrix to match restrictions
-##' imposed by Cai (2010).
+##' models and parameters. If \code{grp} is given then theta, items, params,
+##' mean, and cov can be omitted.
 ##'
 ##' @name rpf.sample
 ##' @param theta either a vector (for 1 dimension) or a matrix (for >1
@@ -16,12 +11,14 @@
 ##' @param items a list of item models
 ##' @param params a list or matrix of item parameters. If omitted, random item
 ##' parameters are generated for each item model.
-##' @param design a matrix assigning person abilities to item factors
+##' @param ...  Not used.  Forces remaining arguments to be specified by name.
 ##' @param prefix Column names are taken from param or items.
 ##' If no column names are available, some will be generated using
 ##' the given prefix.
 ##' @param mean mean vector of latent distribution (optional)
 ##' @param cov covariance matrix of latent distribution (optional)
+##' @param mcar proportion of generated data to set to NA (missing completely at random)
+##' @param grp a list with spec, param, mean, and cov
 ##' @return Returns a data frame of response patterns
 ##' @export
 ##' @examples
@@ -31,46 +28,34 @@
 ##' i2 <- rpf.nrm(outcomes=3)
 ##' i2.p <- rpf.rparam(i2)
 ##' rpf.sample(5, list(i1,i2), list(i1.p, i2.p))
-##'
-##' # multidimensional items
-##' numItems <- 4
-##' items <- vector("list", numItems)
-##' correct <- vector("list", numItems)
-##'
-##' i1 <- rpf.drm(factors=2)
-##' i2 <- rpf.drm(factors=1, multidimensional=TRUE)
-##'
-##' for (ix in 1:(numItems-1)) {
-##'   items[[ix]] <- i1
-##'   correct[[ix]] <- rpf.rparam(i1)
-##' }
-##' items[[4]] <- i2
-##' correct[[4]] <- rpf.rparam(i2)
-##' 
-##' design <- matrix(c(1, 1, 1, 1,
-##'                    2, 2, 3, NA), nrow=2, byrow=TRUE)
-##' rpf.sample(10, items, correct, design)
 ##' @seealso \code{\link{sample}}
-##' @references
-##' Cai, L. (2010). A two-tier full-information item factor analysis
-##' model with applications. \emph{Psychometrika, 75}, 581-612.
-rpf.sample <- function(theta, items, params, design, prefix="i",
-                       mean=NULL, cov=NULL) {
+rpf.sample <- function(theta, items, params, ..., prefix="i",
+                       mean=NULL, cov=NULL, mcar=0.0, grp=NULL)
+{
+    garbageArguments <- list(...)
+    if (length(garbageArguments) > 0) {
+        stop("rpf.sample does not accept values for the '...' argument")
+    }
+
+    if (!missing(grp)) {
+	    if (missing(items)) items <- grp$spec
+	    if (missing(params)) params <- grp$param
+	    if (missing(mean)) mean <- grp$mean
+	    if (missing(cov)) cov <- grp$cov
+	    if (missing(theta)) theta <- nrow(grp$data)
+    }
+
   numItems <- length(items)
   maxDim <- max(vapply(items, function(i) i@factors, 0))
-  if (missing(design)) {
-    if (maxDim > 1) {
-      design <- matrix(rep(1:maxDim, numItems), nrow=maxDim)
-      design[sapply(items, function(i) 1:maxDim > i@factors)] <- NA
-    } else {
-      design <- matrix(rep(1, numItems), nrow=1)
-    }
-  }
-  maxAbilities <- max(design, na.rm=TRUE)
 
-  if (maxDim > 1 && any(dim(design) != c(maxDim,numItems))) {
-    stop(paste("The design matrix must have", maxDim, "rows and ",numItems,"columns"))
-  }
+    if (maxDim > 1) {
+	    design <- matrix(rep(1:maxDim, numItems), nrow=maxDim)
+	    design[sapply(items, function(i) 1:maxDim > i@factors)] <- NA
+    } else {
+	    design <- matrix(rep(1, numItems), nrow=1)
+    }
+
+  maxAbilities <- max(design, na.rm=TRUE)
 
   numPeople <- NA
   if (is.numeric(theta) && length(theta) == 1) {
@@ -129,5 +114,12 @@ rpf.sample <- function(theta, items, params, design, prefix="i",
   if (is.null(name)) name <- names(items)
   if (is.null(name)) name <- paste(prefix,1:numItems,sep="")
   colnames(ret) <- name
+  if (mcar > 0) {
+      size <- prod(dim(ret))
+      mask <- rep(FALSE, size)
+      mask[sample.int(size, size * mcar)] <- TRUE
+      shaped.mask <- array(mask, dim=dim(ret))
+      ret[shaped.mask] <- NA
+  }
   return(ret)
 }
